package
Version:
v0.0.0-...-cd6c0e1
Opens a new window with list of versions in this module.
Published: May 19, 2022
License: GPL-3.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func E(message interface{})
func P(message interface{})
func SetOutput(logFile *os.File)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.